import React, { useEffect, useState } from 'react';
import { Gesture, GestureDetector } from 'react-native-gesture-handler';
import { cancelAnimation, useAnimatedStyle, useSharedValue, withSpring } from 'react-native-reanimated';
import ViewGestureHandlerRootHOC from './ViewGestureHandlerRootHOC';
import { ActivityIndicator, Dimensions, FlatList, Text, View } from 'react-native';
import ThumbnailComponent from './ThumbnailComponent';
import { styles } from './styles';
import { getComplementaryColor } from './Utils';

const SimpleImageView = _ref => {
  var _nowImage$title, _getComplementaryColo;

  let {
    imageUri,
    bgColor,
    images = [],
    viewMode = 'single',
    selectedIndex = 0,
    perPage = 3,
    itemMargin = 15,
    showTitle,
    complementaryBgColor
  } = _ref;
  const DeviceWidth = Dimensions.get('window').width;
  const imageSize = (perPage < 4 ? Math.round(DeviceWidth / 4) : Math.round(DeviceWidth / perPage)) - itemMargin;
  const imageBorderRadius = imageSize * 0.05;
  const tmpImgObj = {
    uri: '',
    title: ''
  };
  const [nowImage, setNowImage] = useState(tmpImgObj);
  const [totPage, setToTPage] = useState(undefined);
  const [imgIndex, setImgIndex] = useState(0);
  const [imgArray, setImgArray] = useState([]);
  const startX = useSharedValue(0);
  const transX = useSharedValue(0);
  const startY = useSharedValue(0);
  const transY = useSharedValue(0);
  const scaleXY = useSharedValue(1);
  const savedScale = useSharedValue(1);
  const rotation = useSharedValue(0);
  const savedRotation = useSharedValue(0);
  useEffect(() => {
    if (viewMode === 'multi' && images && (images === null || images === void 0 ? void 0 : images.length) > 0) {
      var _images$selectedIndex;

      setToTPage(Math.ceil((images === null || images === void 0 ? void 0 : images.length) / perPage));
      setNowImage((_images$selectedIndex = images[selectedIndex]) !== null && _images$selectedIndex !== void 0 ? _images$selectedIndex : imageUri);
    } else {
      setToTPage(1);
      setNowImage(imageUri);
    }
  }, [images, imageUri]);
  useEffect(() => {
    if (totPage && totPage > 0 && (images === null || images === void 0 ? void 0 : images.length) > 0) {
      const newArray = [];
      Array.from({
        length: totPage
      }).forEach((_, index) => {
        newArray.push(images === null || images === void 0 ? void 0 : images.slice(perPage * index, perPage * index + perPage));
      });
      setImgArray(newArray);
    }
  }, [totPage]);
  useEffect(() => {
    if (!imgArray) return;
    setNowImage(tmpImgObj);
    setNowImage(images[imgIndex]);
  }, [imgIndex]);
  const transXYStyle = useAnimatedStyle(() => {
    return {
      transform: [{
        translateX: transX.value
      }, {
        translateY: transY.value
      }, {
        scale: scaleXY.value
      }, {
        rotateZ: `${rotation.value / Math.PI * 180}deg`
      }]
    };
  }, []);

  const scaleAnimation = () => {
    'worklet';

    cancelAnimation(scaleXY);
    cancelAnimation(startX);
    cancelAnimation(startY);
    savedScale.value = 1;
    startX.value = 0;
    startY.value = 0;
    scaleXY.value = withSpring(1);
    transX.value = withSpring(0);
    transY.value = withSpring(0);
    rotation.value = withSpring(0);
    savedRotation.value = 0;
  };

  const panHandler = Gesture.Pan().maxPointers(1).onStart(() => {
    transX.value = startX.value;
    transY.value = startY.value;
  }).onUpdate(event => {
    transX.value = event.translationX + startX.value;
    transY.value = event.translationY + startY.value;
  }).onEnd(() => {
    startX.value = transX.value;
    startY.value = transY.value;
  });
  const pinchHandler = Gesture.Pinch().onUpdate(e => {
    scaleXY.value = savedScale.value * (e.scale > 0 ? e.scale : 1);
  }).onEnd(() => {
    savedScale.value = scaleXY.value > 0 ? scaleXY.value : 1;
  });
  const tapHandler = Gesture.Tap().numberOfTaps(2).maxDelay(300).onEnd(scaleAnimation);
  const rotateHandler = Gesture.Rotation().onUpdate(e => {
    rotation.value = savedRotation.value + e.rotation;
  }).onEnd(() => {
    savedRotation.value = rotation.value;
  });
  const simultaneousHandler = Gesture.Simultaneous(panHandler, pinchHandler, tapHandler, rotateHandler);

  const updateNowImageIndex = (pageIndex, imageIndex) => {
    setImgIndex(pageIndex * perPage + imageIndex);
  };

  const keyExtractor = (_, index) => index.toString();

  const _renderItem = _ref2 => {
    let {
      item,
      index
    } = _ref2;
    return /*#__PURE__*/React.createElement(View, {
      style: [styles.itemContainer, {
        width: DeviceWidth,
        backgroundColor: bgColor
      }]
    }, item === null || item === void 0 ? void 0 : item.map((el, imageIndex) => {
      return /*#__PURE__*/React.createElement(ThumbnailComponent, {
        key: index + ':' + imageIndex,
        nowPage: index,
        imgIndex: imageIndex,
        imgObj: el,
        imageBorderRadius: imageBorderRadius,
        imageSize: imageSize,
        perPage: perPage,
        borderColor: complementaryBgColor,
        updateNowImageIndex: updateNowImageIndex
      });
    }));
  };

  return imageUri !== null && imageUri !== void 0 && imageUri.uri || (images === null || images === void 0 ? void 0 : images.length) > 0 ? /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1,
      backgroundColor: bgColor,
      justifyContent: 'flex-end',
      alignItems: 'center'
    }
  }, showTitle && nowImage !== null && nowImage !== void 0 && nowImage.title && (nowImage === null || nowImage === void 0 ? void 0 : (_nowImage$title = nowImage.title) === null || _nowImage$title === void 0 ? void 0 : _nowImage$title.length) > 0 ? /*#__PURE__*/React.createElement(Text, {
    style: {
      fontSize: 16,
      color: complementaryBgColor
    }
  }, `${nowImage === null || nowImage === void 0 ? void 0 : nowImage.title}`) : null), nowImage && nowImage !== null && nowImage !== void 0 && nowImage.uri ? /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 4,
      backgroundColor: bgColor
    }
  }, /*#__PURE__*/React.createElement(GestureDetector, {
    gesture: simultaneousHandler
  }, /*#__PURE__*/React.createElement(ViewGestureHandlerRootHOC, {
    imageUri: nowImage,
    transXYStyle: transXYStyle,
    bgColor: bgColor
  }))) : /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 4,
      backgroundColor: bgColor,
      justifyContent: 'center',
      alignItems: 'center'
    }
  }, /*#__PURE__*/React.createElement(ActivityIndicator, {
    size: 'small',
    color: (_getComplementaryColo = getComplementaryColor(bgColor)) !== null && _getComplementaryColo !== void 0 ? _getComplementaryColo : '#FFFFFF'
  })), viewMode === 'multi' && totPage && totPage > 0 && imgArray && (imgArray === null || imgArray === void 0 ? void 0 : imgArray.length) > 0 ? /*#__PURE__*/React.createElement(FlatList, {
    ListEmptyComponent: /*#__PURE__*/React.createElement(ActivityIndicator, {
      size: 'large',
      color: complementaryBgColor
    }),
    style: {
      flex: 1
    },
    windowSize: 1,
    initialNumToRender: totPage ? totPage >= 2 ? 2 : totPage : undefined,
    keyExtractor: keyExtractor,
    data: imgArray,
    renderItem: _renderItem,
    horizontal: true,
    pagingEnabled: true,
    removeClippedSubviews: true,
    showsVerticalScrollIndicator: false,
    showsHorizontalScrollIndicator: false,
    onMomentumScrollBegin: undefined,
    onEndReached: undefined,
    onEndReachedThreshold: 0.5
  }) : null) : null;
};

export default SimpleImageView;
//# sourceMappingURL=SimpleImageView.js.map