import React, { useEffect, useState } from 'react';
import Modal from 'react-native-modal';
import SimpleImageView from './SimpleImageView';
import CloseButton from './CloseButton';
import { styles } from './styles';
import { getComplementaryColor } from './Utils';

const SimpleImageViewer = _ref => {
  let {
    isVisible = false,
    imageUri,
    images = [],
    onClose,
    bgColor = '#333333',
    viewMode = 'multi',
    showTitle = false,
    selectedIndex = 0,
    perPage = 3,
    leftHanded = false
  } = _ref;
  const [complementaryBgColor] = useState(getComplementaryColor(bgColor));
  const [thisVisible, setThisVisible] = useState(false);
  useEffect(() => {
    setThisVisible(isVisible);
  }, [isVisible]);

  const closeModal = () => {
    setThisVisible(false);
    if (onClose) onClose(false);
  };

  return /*#__PURE__*/React.createElement(Modal, {
    isVisible: thisVisible,
    animationIn: 'fadeIn',
    animationOut: 'fadeOut',
    style: [styles.modal, {
      backgroundColor: bgColor
    }]
  }, /*#__PURE__*/React.createElement(SimpleImageView, {
    viewMode: viewMode,
    perPage: perPage,
    selectedIndex: selectedIndex,
    imageUri: imageUri,
    images: images,
    showTitle: showTitle,
    bgColor: bgColor,
    complementaryBgColor: complementaryBgColor
  }), /*#__PURE__*/React.createElement(CloseButton, {
    handed: leftHanded,
    onClose: closeModal,
    closeButtonColor: complementaryBgColor
  }));
};

export default SimpleImageViewer;
//# sourceMappingURL=SimpleImageViewer.js.map